;; Interface with 'wc' command
;; Coded by K.Handa, Electrotechnical Lab. (handa@etl.go.jp)
;;      and S.Tomura, Electrotechnical Lab. (tomura@etl.go.jp)

;; This file is part of Nemacs (Japanese version of GNU Emacs).

;; Nemacs is distributed in the forms of patches to GNU
;; Emacs under the terms of the GNU EMACS GENERAL PUBLIC
;; LICENSE which is distributed along with GNU Emacs by the
;; Free Software Foundation.

;; Nemacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied
;; warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
;; PURPOSE.  See the GNU EMACS GENERAL PUBLIC LICENSE for
;; more details.

;; You should have received a copy of the GNU EMACS GENERAL
;; PUBLIC LICENSE along with Nemacs; see the file COPYING.
;; If not, write to the Free Software Foundation, 675 Mass
;; Ave, Cambridge, MA 02139, USA.

;;; 89.7.28  created by K.Handa

(defun wc-region (from to)
  (interactive "r")
  (wc-call-wc from to))

(defun wc-paragraph ()
  (interactive)
  (save-excursion
    (backward-paragraph)
    (let ((p (point)))
      (forward-paragraph)
      (wc-call-wc p (point)))))

(defun wc-buffer ()
  (interactive)
  (save-excursion
    (wc-call-wc (point-min) (point-max))))

(defun wc-call-wc (from to)
  (let (str
	(buf (get-buffer-create "*wc*")))
    (save-excursion
      (set-buffer buf)
      (erase-buffer))
    (call-process-region from to "wc" nil buf)
    (save-excursion
      (set-buffer buf)
      (goto-char (point-min))
      (re-search-forward "\\(\\w+\\)\\s *\\(\\w+\\)\\s *\\(\\w+\\)")
      (message "%s lines %s words %s characters"
	       (buffer-substring (match-beginning 1) (match-end 1))
	       (buffer-substring (match-beginning 2) (match-end 2))
	       (buffer-substring (match-beginning 3) (match-end 3))))
    (kill-buffer buf)))
